==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebToggleViewEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebToggleViewEventArgsDetailDescription } from "./WebToggleViewEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebToggleViewEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebToggleViewEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebToggleViewEventArgsDetailDescriptionMetadata.a == null) {
                WebToggleViewEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebToggleViewEventArgsDetailDescriptionMetadata.c(WebToggleViewEventArgsDetailDescriptionMetadata.a);
            }
            if (a.j(WebToggleViewEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.y(WebToggleViewEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ToggleViewEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Id", "String");
        }
        static d(a) {
            WebToggleViewEventArgsDetailDescriptionMetadata.b(a);
            a.aa("WebToggleViewEventArgsDetail", () => new WebToggleViewEventArgsDetailDescription());
            a.z("WebToggleViewEventArgsDetail", WebToggleViewEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebToggleViewEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebToggleViewEventArgsDetailDescriptionMetadata, 'WebToggleViewEventArgsDetailDescriptionMetadata');
    WebToggleViewEventArgsDetailDescriptionMetadata.a = null;
    return WebToggleViewEventArgsDetailDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebToggleViewEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebToggleViewEventArgsDetailDescription } from "./WebToggleViewEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebToggleViewEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebToggleViewEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebToggleViewEventArgsDetailDescriptionMetadata.a == null) {
                WebToggleViewEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebToggleViewEventArgsDetailDescriptionMetadata.c(WebToggleViewEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebToggleViewEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebToggleViewEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ToggleViewEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Id", "String");
        }
        static d(a) {
            WebToggleViewEventArgsDetailDescriptionMetadata.b(a);
            a.ac("WebToggleViewEventArgsDetail", () => new WebToggleViewEventArgsDetailDescription());
            a.ab("WebToggleViewEventArgsDetail", WebToggleViewEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebToggleViewEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebToggleViewEventArgsDetailDescriptionMetadata, 'WebToggleViewEventArgsDetailDescriptionMetadata');
    WebToggleViewEventArgsDetailDescriptionMetadata.a = null;
    return WebToggleViewEventArgsDetailDescriptionMetadata;
})();
